@@ -1,29 +1,20 @@
 package Net::SNMPTrapd;
 
 ########################################################
-#
 # AUTHOR = Michael Vincent
 # www.VinsWorld.com
-#
 ########################################################
 
-require 5.005;
-
 use strict;
-use Exporter;
+use warnings;
 use Convert::ASN1;
 use Socket qw(inet_ntoa AF_INET IPPROTO_TCP);
 
 my $AF_INET6 = eval { Socket::AF_INET6() };
 my $NI_NUMERICHOST = eval { Socket::NI_NUMERICHOST() };
 
-our $VERSION     = '0.12';
-our @ISA         = qw(Exporter);
-our @EXPORT      = qw();
-our %EXPORT_TAGS = (
-                    'all' => [qw()]
-                   );
-our @EXPORT_OK   = (@{$EXPORT_TAGS{'all'}});
+our $VERSION = '0.13';
+our @ISA;
 
 my $HAVE_IO_Socket_IP = 0;
 eval "use IO::Socket::IP -register";
@@ -43,8 +34,8 @@ use constant SNMPTRAPD_RFC_SIZE     => 484;   # RFC limit
 use constant SNMPTRAPD_REC_SIZE     => 1472;  # Recommended size
 use constant SNMPTRAPD_MAX_SIZE     => 65467; # Actual limit (65535 - IP/UDP)
 
-our @TRAPTYPES = qw(COLDSTART WARMSTART LINKDOWN LINKUP AUTHFAIL EGPNEIGHBORLOSS ENTERPRISESPECIFIC);
-our @PDUTYPES  = qw(GetRequest GetNextRequest Response SetRequest Trap GetBulkRequest InformRequest SNMPv2-Trap Report);
+my @TRAPTYPES = qw(COLDSTART WARMSTART LINKDOWN LINKUP AUTHFAIL EGPNEIGHBORLOSS ENTERPRISESPECIFIC);
+my @PDUTYPES  = qw(GetRequest GetNextRequest Response SetRequest Trap GetBulkRequest InformRequest SNMPv2-Trap Report);
 our $LASTERROR;
 
 my $asn = Convert::ASN1->new;
@@ -102,7 +93,7 @@ $asn->prepare("
         }
     }
 ");
-our $snmpasn = $asn->find('PDU');
+my $snmpasn = $asn->find('PDU');
 
 ########################################################
 # End Variables
@@ -126,35 +117,35 @@ sub new {
 
     if (@_ == 1) {
         $LASTERROR = "Insufficient number of args - @_";
-        return(undef)
+        return undef
     } else {
         my %cfg = @_;
         for (keys(%cfg)) {
             if (/^-?localport$/i) {
-                $params{'LocalPort'} = $cfg{$_}
+                $params{LocalPort} = $cfg{$_}
             } elsif (/^-?localaddr$/i) {
-                $params{'LocalAddr'} = $cfg{$_}
+                $params{LocalAddr} = $cfg{$_}
             } elsif (/^-?family$/i) {
                  if ($cfg{$_} =~ /^(?:(?:(:?ip)?v?(?:4|6))|${\AF_INET}|$AF_INET6)$/) {
                     if ($cfg{$_} =~ /^(?:(?:(:?ip)?v?4)|${\AF_INET})$/) {
-                        $params{'Family'} = AF_INET
+                        $params{Family} = AF_INET
                     } else {
                         if (!$HAVE_IO_Socket_IP) {
                             $LASTERROR = "IO::Socket::IP required for IPv6";
-                            return(undef)
+                            return undef
                         }
-                        $params{'Family'} = $AF_INET6
+                        $params{Family} = $AF_INET6
                     }
                 } else {
                     $LASTERROR = "Invalid family - $cfg{$_}";
-                    return(undef)
+                    return undef
                 }
             } elsif (/^-?timeout$/i) {
                 if ($cfg{$_} =~ /^\d+$/) {
-                    $params{'Timeout'} = $cfg{$_}
+                    $params{Timeout} = $cfg{$_}
                 } else {
                     $LASTERROR = "Invalid timeout - $cfg{$_}";
-                    return(undef)
+                    return undef
                 }
             }
         }
@@ -167,7 +158,7 @@ sub new {
                      }, $class
     } else {
         $LASTERROR = "Error opening socket for listener: $@";
-        return(undef)
+        return undef
     }
 }
 
@@ -186,7 +177,7 @@ sub get_trap {
     my $datagramsize = SNMPTRAPD_MAX_SIZE;
     if (@_ == 1) {
         $LASTERROR = "Insufficient number of args: @_";
-        return(undef)
+        return undef
     } else {
         my %args = @_;        
         for (keys(%args)) {
@@ -202,22 +193,22 @@ sub get_trap {
                     $datagramsize = SNMPTRAPD_REC_SIZE
                 } else {
                     $LASTERROR = "Not a valid size: $args{$_}";
-                    return(undef)
+                    return undef
                 }
             # -timeout
             } elsif (/^-?timeout$/i) {
                 if ($args{$_} =~ /^\d+$/) {
-                    $trap->{'Timeout'} = $args{$_}
+                    $trap->{Timeout} = $args{$_}
                 } else {
                     $LASTERROR = "Invalid timeout - $args{$_}";
-                    return(undef)
+                    return undef
                 }
             }
         }
     }
 
-    my $Timeout = $trap->{'Timeout'};
-    my $udpserver = $self->{'_UDPSERVER_'};
+    my $Timeout = $trap->{Timeout};
+    my $udpserver = $self->{_UDPSERVER_};
     my $datagram;
 
     if ($Timeout != 0) {
@@ -235,15 +226,15 @@ sub get_trap {
     # read the message
     if ($udpserver->recv($datagram, $datagramsize)) {
 
-        $trap->{'_TRAP_'}{'PeerPort'} = $udpserver->SUPER::peerport;
-        $trap->{'_TRAP_'}{'PeerAddr'} = $udpserver->SUPER::peerhost;
-        $trap->{'_TRAP_'}{'datagram'} = $datagram;
+        $trap->{_TRAP_}{PeerPort} = $udpserver->SUPER::peerport;
+        $trap->{_TRAP_}{PeerAddr} = $udpserver->SUPER::peerhost;
+        $trap->{_TRAP_}{datagram} = $datagram;
 
         return bless $trap, $class
     }
 
     $LASTERROR = sprintf "Socket RECV error: $!";
-    return(undef)
+    return undef
 }
 
 sub process_trap {
@@ -255,13 +246,13 @@ sub process_trap {
     if (($self eq $class) && ($class eq __PACKAGE__)) {
         my %th;
         $self = \%th;
-        ($self->{'_TRAP_'}{'datagram'}) = @_
+        ($self->{_TRAP_}{datagram}) = @_
     }
     # Net::SNMPTrapd::process_trap($data)
     if ($class ne __PACKAGE__) {
         my %th;
         $self = \%th;
-        ($self->{'_TRAP_'}{'datagram'}) = $class;
+        ($self->{_TRAP_}{datagram}) = $class;
         $class = __PACKAGE__
     }
 
@@ -272,7 +263,7 @@ sub process_trap {
         for (keys(%args)) {
             # -datagram
             if ((/^-?data(?:gram)?$/i) || (/^-?pdu$/i)) {
-                $self->{'_TRAP_'}{'datagram'} = $args{$_}
+                $self->{_TRAP_}{datagram} = $args{$_}
             # -noresponse
             } elsif (/^-?noresponse$/i) {
                 if (($args{$_} =~ /^\d+$/) && ($args{$_} > 0)) {
@@ -283,179 +274,179 @@ sub process_trap {
     }
 
     my $trap;
-    if (!defined($trap = $snmpasn->decode($self->{'_TRAP_'}{'datagram'}))) {
+    if (!defined($trap = $snmpasn->decode($self->{_TRAP_}{datagram}))) {
         $LASTERROR = sprintf "Error decoding PDU - %s", (defined($snmpasn->error) ? $snmpasn->error : "Unknown Convert::ASN1->decode() error.  Consider $class dump()");
-        return(undef)
+        return undef
     }
     #DEBUG: use Data::Dumper; print Dumper \$trap;
 
     # Only understand SNMPv1 (0) and v2c (1)
-    if ($trap->{'version'} > 1) {
-        $LASTERROR = sprintf "Unrecognized SNMP version - %i", $trap->{'version'};
-        return(undef)
+    if ($trap->{version} > 1) {
+        $LASTERROR = sprintf "Unrecognized SNMP version - %i", $trap->{version};
+        return undef
     }
 
     # set PDU Type for later use
-    my $pdutype = sprintf "%s", keys(%{$trap->{'pdu_type'}});
+    my $pdutype = sprintf "%s", keys(%{$trap->{pdu_type}});
 
     ### Assemble decoded trap object
     # Common
-    $self->{'_TRAP_'}{'version'} = $trap->{'version'};
-    $self->{'_TRAP_'}{'community'} = $trap->{'community'};
+    $self->{_TRAP_}{version} = $trap->{version};
+    $self->{_TRAP_}{community} = $trap->{community};
     if ($pdutype eq 'trap') {
-        $self->{'_TRAP_'}{'pdu_type'} = 4
+        $self->{_TRAP_}{pdu_type} = 4
     
     } elsif ($pdutype eq 'inform_request') {
-        $self->{'_TRAP_'}{'pdu_type'} = 6;
+        $self->{_TRAP_}{pdu_type} = 6;
 
         # send response for InformRequest
         if ($RESPONSE) {
-            if ((my $r = &_InformRequest_Response(\$self, $trap, $pdutype)) ne 'OK') {
+            if ((my $r = _InformRequest_Response(\$self, $trap, $pdutype)) ne 'OK') {
                 $LASTERROR = sprintf "Error sending InformRequest Response - %s", $r;
-                return(undef)
+                return undef
             }
         }
 
     } elsif ($pdutype eq 'snmpv2_trap') { 
-        $self->{'_TRAP_'}{'pdu_type'} = 7
+        $self->{_TRAP_}{pdu_type} = 7
     }
 
     # v1
-    if ($trap->{'version'} == 0) {
-        $self->{'_TRAP_'}{'ent_oid'}       =          $trap->{'pdu_type'}->{$pdutype}->{'ent_oid'};
-        $self->{'_TRAP_'}{'agent_addr'}    = inetNtoa($trap->{'pdu_type'}->{$pdutype}->{'agent_addr'});
-        $self->{'_TRAP_'}{'generic_trap'}  =          $trap->{'pdu_type'}->{$pdutype}->{'generic_trap'};
-        $self->{'_TRAP_'}{'specific_trap'} =          $trap->{'pdu_type'}->{$pdutype}->{'specific_trap'};
-        $self->{'_TRAP_'}{'timeticks'}     =          $trap->{'pdu_type'}->{$pdutype}->{'timeticks'};
+    if ($trap->{version} == 0) {
+        $self->{_TRAP_}{ent_oid}       =           $trap->{pdu_type}->{$pdutype}->{ent_oid};
+        $self->{_TRAP_}{agent_addr}    = _inetNtoa($trap->{pdu_type}->{$pdutype}->{agent_addr});
+        $self->{_TRAP_}{generic_trap}  =           $trap->{pdu_type}->{$pdutype}->{generic_trap};
+        $self->{_TRAP_}{specific_trap} =           $trap->{pdu_type}->{$pdutype}->{specific_trap};
+        $self->{_TRAP_}{timeticks}     =           $trap->{pdu_type}->{$pdutype}->{timeticks};
 
     # v2c
-    } elsif ($trap->{'version'} == 1) {
-        $self->{'_TRAP_'}{'request_id'}   = $trap->{'pdu_type'}->{$pdutype}->{'request_id'};
-        $self->{'_TRAP_'}{'error_status'} = $trap->{'pdu_type'}->{$pdutype}->{'error_status'};
-        $self->{'_TRAP_'}{'error_index'}  = $trap->{'pdu_type'}->{$pdutype}->{'error_index'};
+    } elsif ($trap->{version} == 1) {
+        $self->{_TRAP_}{request_id}   = $trap->{pdu_type}->{$pdutype}->{request_id};
+        $self->{_TRAP_}{error_status} = $trap->{pdu_type}->{$pdutype}->{error_status};
+        $self->{_TRAP_}{error_index}  = $trap->{pdu_type}->{$pdutype}->{error_index};
     }
 
     # varbinds
     my @varbinds;
-    for my $i (0..$#{$trap->{'pdu_type'}->{$pdutype}->{'varbindlist'}}) {
+    for my $i (0..$#{$trap->{pdu_type}->{$pdutype}->{varbindlist}}) {
         my %oidval;
-        for (keys(%{$trap->{'pdu_type'}->{$pdutype}->{'varbindlist'}[$i]->{'value'}})) {
+        for (keys(%{$trap->{pdu_type}->{$pdutype}->{varbindlist}[$i]->{value}})) {
             # defined
-            if (defined($trap->{'pdu_type'}->{$pdutype}->{'varbindlist'}[$i]->{'value'}{$_})) {
+            if (defined($trap->{pdu_type}->{$pdutype}->{varbindlist}[$i]->{value}{$_})) {
                 # special cases:  IP address, null
                 if ($_ eq 'ipaddr') {
-                    $oidval{$trap->{'pdu_type'}->{$pdutype}->{'varbindlist'}[$i]->{'oid'}} = inetNtoa($trap->{'pdu_type'}->{$pdutype}->{'varbindlist'}[$i]->{'value'}{$_})
+                    $oidval{$trap->{pdu_type}->{$pdutype}->{varbindlist}[$i]->{oid}} = _inetNtoa($trap->{pdu_type}->{$pdutype}->{varbindlist}[$i]->{value}{$_})
                 } elsif ($_ eq 'null') {
-                    $oidval{$trap->{'pdu_type'}->{$pdutype}->{'varbindlist'}[$i]->{'oid'}} = '(NULL)'
+                    $oidval{$trap->{pdu_type}->{$pdutype}->{varbindlist}[$i]->{oid}} = '(NULL)'
                 # no special case:  just assign it
                 } else {
-                    $oidval{$trap->{'pdu_type'}->{$pdutype}->{'varbindlist'}[$i]->{'oid'}} =          $trap->{'pdu_type'}->{$pdutype}->{'varbindlist'}[$i]->{'value'}{$_}
+                    $oidval{$trap->{pdu_type}->{$pdutype}->{varbindlist}[$i]->{oid}} =           $trap->{pdu_type}->{$pdutype}->{varbindlist}[$i]->{value}{$_}
                 }
             # not defined - ""
             } else {
-                $oidval{$trap->{'pdu_type'}->{$pdutype}->{'varbindlist'}[$i]->{'oid'}} = ""
+                $oidval{$trap->{pdu_type}->{$pdutype}->{varbindlist}[$i]->{oid}} = ""
             }
         }
         push @varbinds, \%oidval
     }
-    $self->{'_TRAP_'}{'varbinds'} = \@varbinds;
+    $self->{_TRAP_}{varbinds} = \@varbinds;
 
     return bless $self, $class
 }
 
 sub server {
     my $self = shift;
-    return $self->{'_UDPSERVER_'}
+    return $self->{_UDPSERVER_}
 }
 
 sub datagram {
     my ($self, $arg) = @_;
 
     if (defined($arg) && ($arg >= 1)) {
-        return unpack ('H*', $self->{'_TRAP_'}{'datagram'})
+        return unpack ('H*', $self->{_TRAP_}{datagram})
     } else {
-        return $self->{'_TRAP_'}{'datagram'}
+        return $self->{_TRAP_}{datagram}
     }
 }
 
 sub remoteaddr {
     my $self = shift;
-    return $self->{'_TRAP_'}{'PeerAddr'}
+    return $self->{_TRAP_}{PeerAddr}
 }
 
 sub remoteport {
     my $self = shift;
-    return $self->{'_TRAP_'}{'PeerPort'}
+    return $self->{_TRAP_}{PeerPort}
 }
 
 sub version {
     my $self = shift;
-    return $self->{'_TRAP_'}{'version'} + 1
+    return $self->{_TRAP_}{version} + 1
 }
 
 sub community {
     my $self = shift;
-    return $self->{'_TRAP_'}{'community'}
+    return $self->{_TRAP_}{community}
 }
 
 sub pdu_type {
     my ($self, $arg) = @_;
 
     if (defined($arg) && ($arg >= 1)) {
-        return $self->{'_TRAP_'}{'pdu_type'}
+        return $self->{_TRAP_}{pdu_type}
     } else {
-        return $PDUTYPES[$self->{'_TRAP_'}{'pdu_type'}]
+        return $PDUTYPES[$self->{_TRAP_}{pdu_type}]
     }
 }
 
 sub ent_OID {
     my $self = shift;
-    return $self->{'_TRAP_'}{'ent_oid'}
+    return $self->{_TRAP_}{ent_oid}
 }
 
 sub agentaddr {
     my $self = shift;
-    return $self->{'_TRAP_'}{'agent_addr'}
+    return $self->{_TRAP_}{agent_addr}
 }
 
 sub generic_trap {
     my ($self, $arg) = @_;
 
     if (defined($arg) && ($arg >= 1)) {
-        return $self->{'_TRAP_'}{'generic_trap'}
+        return $self->{_TRAP_}{generic_trap}
     } else {
-        return $TRAPTYPES[$self->{'_TRAP_'}{'generic_trap'}]
+        return $TRAPTYPES[$self->{_TRAP_}{generic_trap}]
     }
 }
 
 sub specific_trap {
     my $self = shift;
-    return $self->{'_TRAP_'}{'specific_trap'}
+    return $self->{_TRAP_}{specific_trap}
 }
 
 sub timeticks {
     my $self = shift;
-    return $self->{'_TRAP_'}{'timeticks'}
+    return $self->{_TRAP_}{timeticks}
 }
 
 sub request_ID {
     my $self = shift;
-    return $self->{'_TRAP_'}{'request_id'}
+    return $self->{_TRAP_}{request_id}
 }
 
 sub error_status {
     my $self = shift;
-    return $self->{'_TRAP_'}{'error_status'}
+    return $self->{_TRAP_}{error_status}
 }
 
 sub error_index {
     my $self = shift;
-    return $self->{'_TRAP_'}{'error_index'}
+    return $self->{_TRAP_}{error_index}
 }
 
 sub varbinds {
     my $self = shift;
-    return $self->{'_TRAP_'}{'varbinds'}
+    return $self->{_TRAP_}{varbinds}
 }
 
 sub error {
@@ -471,22 +462,22 @@ sub dump {
     if (($self eq $class) && ($class eq __PACKAGE__)) {
         my %th;
         $self = \%th;
-        ($self->{'_TRAP_'}{'datagram'}) = @_
+        ($self->{_TRAP_}{datagram}) = @_
     }
     # Net::SNMPTrapd::dump($datagram)
     if ($class ne __PACKAGE__) {
         my %th;
         $self = \%th;
-        ($self->{'_TRAP_'}{'datagram'}) = $class;
+        ($self->{_TRAP_}{datagram}) = $class;
         $class = __PACKAGE__
     }
 
-    if (defined($self->{'_TRAP_'}{'datagram'})) {
-        Convert::ASN1::asn_dump($self->{'_TRAP_'}{'datagram'});
-        Convert::ASN1::asn_hexdump($self->{'_TRAP_'}{'datagram'});
+    if (defined($self->{_TRAP_}{datagram})) {
+        Convert::ASN1::asn_dump($self->{_TRAP_}{datagram});
+        Convert::ASN1::asn_hexdump($self->{_TRAP_}{datagram});
     } else {
         $LASTERROR = "Missing datagram to dump";
-        return(undef)
+        return undef
     }
 
     return 1
@@ -506,40 +497,39 @@ sub _InformRequest_Response {
     my $class = ref($$self) || $$self;
 
     # Change from request to response
-    $trap->{'pdu_type'}{'response'} = delete $trap->{'pdu_type'}{'inform_request'};
+    $trap->{pdu_type}{response} = delete $trap->{pdu_type}{inform_request};
 
     my $buffer = $snmpasn->encode($trap);
     if (!defined($buffer)) {
         return $snmpasn->error
     }
     #DEBUG print "BUFFER = $buffer\n";
-
-    if ($$self->{'_TRAP_'}->{'PeerAddr'} eq "") {
+    if (!defined($$self->{_TRAP_}->{PeerAddr}) || ($$self->{_TRAP_}->{PeerAddr} eq "")) {
         return "Peer Addr undefined"
     }
-    if ($$self->{'_TRAP_'}->{'PeerPort'} == 0) {
+    if (!defined($$self->{_TRAP_}->{PeerPort}) || ($$self->{_TRAP_}->{PeerPort} == 0)) {
         return "Peer Port undefined"
     }
 
     my $socket = $class->SUPER::new(
-                                     Proto     => "udp",
-                                     PeerAddr  => $$self->{'_TRAP_'}->{'PeerAddr'},
-                                     PeerPort  => $$self->{'_TRAP_'}->{'PeerPort'},
-                                     # LocalPort should be set, but creates error.
-                                     # Tried setting ReusePort on initial server,
-                                     # but not implemented on Windows.  What to do?
-                                     #LocalPort => SNMPTRAPD_DEFAULT_PORT,
-                                     Family    => $$self->{'Family'}
-                                    ) || return "Can't create Response socket";
+        Proto     => "udp",
+        PeerAddr  => $$self->{_TRAP_}->{PeerAddr},
+        PeerPort  => $$self->{_TRAP_}->{PeerPort},
+        # LocalPort should be set, but creates error.
+        # Tried setting ReusePort on initial server,
+        # but not implemented on Windows.  What to do?
+        #LocalPort => SNMPTRAPD_DEFAULT_PORT,
+        Family    => $$self->{Family}
+    ) || return "Can't create Response socket";
     $socket->send($buffer);
     close $socket;
 
     # Change back to request from response
-    $trap->{'pdu_type'}{'inform_request'} = delete $trap->{'pdu_type'}{'response'};
+    $trap->{pdu_type}{inform_request} = delete $trap->{pdu_type}{response};
     return ("OK")
 }
 
-sub inetNtoa {
+sub _inetNtoa {
     my ($addr) = @_;
 
     if ($Socket::VERSION >= 1.94) {
